@@ -22,5 +22,5 @@
 
 for d in $SEQUENTIALDIRS
 do
-    $SHELL run.sh "${@}" "$d" 2>&1 | tee "test.output.$d"
+    $SHELL legacy.run.sh "${@}" "$d" 2>&1 | tee "test.output.$d"
 done
